@@ -1,6 +1,10 @@
 # generate a data.frame of ML horizonation
 # using the output from slab() and a vector of horizon names
 get.ml.hz <- function(x, hz.names) {
+  
+  # trick R CMD check
+  top = bottom = NULL
+  
 	# get index to max probability, 
 	# but only when there is at least one value > 0
 	f.ML.hz <- function(i) {
