@@ -19,8 +19,6 @@
 ## TODO: we are suppressing warnings from daisy() when input is all NA
 ##       this is fine for now, but we should figure out a better way
 
-## TODO: decide: rescaling D --  D / max(D) ? or [0,1]
-
 ## TODO: allow for other distance-computing functions
 ## TODO: allow for 'weights' argument (when metric = 'Gower') to daisy()
 
@@ -102,7 +100,6 @@ rescale.result=FALSE, verbose=FALSE) {
 	## unroll each named soil property, for each soil profile
 	## the result is a list matricies with dimensions: depth, num_properties 
 	# this approach requires a named list of soil properties
-	message(paste("Unrolling ", n.profiles, " Profiles", sep=""))
 	s.unrolled <- dlply(s, "id", .progress=progress, .fun=function(di, p=vars, d=max_d, strict=strict_hz_eval, .parallel=getOption('AQP_parallel', default=FALSE)) {
 		
 		# iterate over the set of properties, unrolling as we go
@@ -132,6 +129,8 @@ rescale.result=FALSE, verbose=FALSE) {
 		# evaluated based on presence of real data in at least 1 variable
 		s.sub <- na.omit(s[, c('id', 'top', 'bottom', vars)])
     
+    ## BUG!!! tapply() re-orders the results based on sorting of s.sub$id
+    ## ----> this will cause problems when input isn't sorted by ID
 		# get the depth of each profile
 		s.slices_of_soil <- tapply(s.sub$bottom, s.sub$id, max, na.rm=TRUE)
 		
@@ -144,7 +143,7 @@ rescale.result=FALSE, verbose=FALSE) {
 		# init a matrix with dimensions: depth slices, number of profiles
 		soil.matrix <- matrix(ncol=s.slices_of_soil.length, nrow=max_d)
 		
-		# file with TRUE for 'soil' or FALSE for 'non-soil'
+		# fill with TRUE for 'soil' or FALSE for 'non-soil'
 		for(s.i in 1:s.slices_of_soil.length) {
 			soil.matrix[, s.i] <- c(rep(TRUE, s.slices_of_soil[s.i]), rep(FALSE, s.slices_of_non_soil[s.i]))
 		}
@@ -165,6 +164,7 @@ rescale.result=FALSE, verbose=FALSE) {
 		  axis(side=2, at=pretty(c(0, depth_slice_seq)), las=1)
 		  axis(side=1, at=1:n.profiles, labels=labs, las=2, cex.axis=0.75)
 		  }
+    
 		# cleanup
 		rm(s.sub)
 		}
@@ -173,7 +173,7 @@ rescale.result=FALSE, verbose=FALSE) {
 	##
 	## new version for computing slice-wise dissimilarities... fast! 
 	## 
-	message("Computing Dissimilarity Matrices", appendLF=FALSE)
+	message(paste('Computing dissimilarity matrices from', n.profiles, 'profiles'), appendLF=FALSE)
 	
 	## TEMP HACK to supress warnings generated by calling daisy with all NA input
 	ow <- options('warn')
@@ -282,7 +282,7 @@ rescale.result=FALSE, verbose=FALSE) {
 	
 	
 	##
-	message("Computing Profile Total Dissimilarities")
+	message("Computing profile total dissimilarities")
 	
 	# reduce list of dissimilarity matrices by summation
 	D <- .SumDistanceList(d)
@@ -293,11 +293,11 @@ rescale.result=FALSE, verbose=FALSE) {
 	# remove previous warnings about NA
 	attr(D, 'NA.message') <- NULL
 	
-	# optionally rescale to 0-1
+	# normalize by dividing by max(D)
 	# this is important when incorporating site data
 	# causes problems for some functions like sammon
 	if(rescale.result)
-		D <- rescale(D)
+		D <- D/max(D, na.rm=TRUE)
 	
 	## DEBUG
 	if(verbose) {
@@ -337,6 +337,7 @@ pc.SPC <- function(s, vars, rescale.result=FALSE, ...){
 		vars <- vars[-matching.idx]
 		
 		
+    ## TODO: BUG!!! horizon data are rescaled via D/max(D) !!!
 		## TODO: allow user to pass-in variable type information
 		# compute dissimilarty on site-level data: only works with 2 or more variables
 		# rescale to [0,1]
@@ -352,8 +353,7 @@ pc.SPC <- function(s, vars, rescale.result=FALSE, ...){
 			## ... but why ? read-up on daisy
 			if(any(is.na(d.site))) {
 				warning('NA in site-level dissimilarity matrix, replacing with min dissimilarity', call.=FALSE)
-				# we have re-scaled to [0,1] so D_min is 0
-				d.site[which(is.na(d.site))] <- 0
+				d.site[which(is.na(d.site))] <- min(d.site, na.rm=TRUE)
 			}
 			
 			## TODO: ordering of D_hz vs D_site ... assumptions safe?
